@@ -22,18 +22,18 @@ def authorize(scope):
 
             if tenant_id is not None:
                 scopes = get_scopes(tenant_id)
-                if scope in scopes:
-                    return endpoint_func(*args, **kwargs)
-                else:
-                    return abort(403, "NOT ALLOWED")
-            # TODO: (cjk) Implement flow for (admin) users without a tenant
             else:
-                return abort(501, "NOT IMPLEMENTED")
+                scopes = get_scopes()
+
+            if scope in scopes:
+                return endpoint_func(*args, **kwargs)
+            else:
+                return abort(403, "NOT ALLOWED")
         return decorated_function
     return decorator
 
 
-def get_scopes(tenant_id):
+def get_scopes(tenant_id=None):
     # TODO: (cjk) Check for jwt payload in the headers when dealing with requests passed through an api gateway
     # jwt_payload = request.headers.get("X-Apigateway-Api-Userinfo")
     auth_header = request.headers.get("Authorization")
@@ -46,7 +46,18 @@ def get_scopes(tenant_id):
 
         if tenant_id == decoded_token.get('firebase').get('tenant'):
             if host:
-                roles = get_roles()
+                roles = get_user_roles()
+                scopes = []
+                for role in roles:
+                    if role['name'] in user_roles:
+                        scopes.extend(role["scopes"])
+                return scopes
+            else:
+                logger.error("Failed to retrieve roles. ROLES_HOST is not set.")
+                return abort(500, "INTERNAL SERVER ERROR")
+        else:
+            if host:
+                roles = get_platform_roles()
                 scopes = []
                 for role in roles:
                     if role['name'] in user_roles:
@@ -58,11 +69,24 @@ def get_scopes(tenant_id):
     return abort(403, "NOT ALLOWED")
 
 
-def get_roles():
+def get_user_roles():
     db = firestore.client()
     roles = []
 
-    roles_ref = db.collection(u'roles')
+    roles_ref = db.collection(u'userRoles')
+    docs = roles_ref.stream()
+
+    for doc in docs:
+        roles.append(doc.to_dict())
+
+    return roles
+
+
+def get_platform_roles():
+    db = firestore.client()
+    roles = []
+
+    roles_ref = db.collection(u'platformRoles')
     docs = roles_ref.stream()
 
     for doc in docs:
